==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/plugins/advlink/langs/es_dlg.js <==
tinyMCE.addI18n('es.advlink_dlg',{
title:"Insertar/editar hiperv\u00EDnculo",
url:"URL del hiperv\u00EDnculo",
target:"Destino",
titlefield:"T\u00EDtulo",
is_email:"La URL que ha introducido parece ser una direci\u00F3n de correo, \u00BFdesea agregar el prefijo mailto: necesario?",
is_external:"La URL que ha introducido parece ser un v\u00EDnculo externo, \u00BFdesea agregar el prefijo http:// necesario?",
list:"Lista de v\u00EDnculos",
general_tab:"General",
popup_tab:"Ventana emergente",
events_tab:"Eventos",
advanced_tab:"Avanzado",
general_props:"Propiedades generales",
popup_props:"Propiedades de ventanas emergentes",
event_props:"Eventos",
advanced_props:"Propiedades avanzadas",
popup_opts:"Opciones",
anchor_names:"Anclas",
target_same:"Abrir en esta ventana / marco",
target_parent:"Abrir en ventana padre / marco",
target_top:"Abrir en el marco superior (reemplaza todos los marcos)",
target_blank:"Abrir en ventana nueva",
popup:"Javascript popup",
popup_url:"URL de la ventana emergente",
popup_name:"Nombre de la ventana",
popup_return:"Insertar 'return false'",
popup_scrollbars:"Barras de desplazamiento",
popup_statusbar:"Barra de estado",
popup_toolbar:"Barra de herramientas",
popup_menubar:"Barra de men\u00FA",
popup_location:"Barra de localizaci\u00F3n",
popup_resizable:"Permitir cambiar el tama\u00F1o de la ventana",
popup_dependent:"Dependientes (s\u00F3lo Mozilla/Firefox)",
popup_size:"Tama\u00F1o",
popup_position:"Posici\u00F3n (X/Y)",
id:"Id",
style:"Estilo",
classes:"Clases",
target_name:"Nombre del Target",
langdir:"Direcci\u00F3n del lenguaje",
target_langcode:"Lenguaje del Target",
langcode:"C\u00F3digo del lenguaje",
encoding:"Codificaci\u00F3n de caracteres del Target",
mime:"Tipo MIME del Target",
rel:"Relaci\u00F3n p\u00E1gina a target",
rev:"Relaci\u00F3n target a p\u00E1gina",
tabindex:"\u00CDndice de tabulaci\u00F3n",
accesskey:"Tecla de acceso",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
link_list:"Lista de v\u00EDnculo"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/advlink/langs/es_dlg.js <==
tinyMCE.addI18n('es.advlink_dlg',{
title:"Insertar/editar hiperv\u00EDnculo",
url:"URL del hiperv\u00EDnculo",
target:"Destino",
titlefield:"T\u00EDtulo",
is_email:"La URL que ha introducido parece ser una direci\u00F3n de correo,  \u00BFdesea agregar el prefijo mailto: necesario?",
is_external:"La URL que ha introducido parece ser un v\u00EDnculo externo,  \u00BFdesea agregar el prefijo http:// necesario?",
list:"Lista de v\u00EDnculos",
general_tab:"General",
popup_tab:"Ventana emergente",
events_tab:"Eventos",
advanced_tab:"Avanzado",
general_props:"Propiedades generales",
popup_props:"Propiedades de ventanas emergentes",
event_props:"Eventos",
advanced_props:"Propiedades avanzadas",
popup_opts:"Opciones",
anchor_names:"Anclas",
target_same:"Abrir en esta ventana / marco",
target_parent:"Abrir en ventana padre / marco",
target_top:"Abrir en el marco superior (reemplaza todos los marcos)",
target_blank:"Abrir en ventana nueva",
popup:"Javascript popup",
popup_url:"URL de la ventana emergente",
popup_name:"Nombre de la ventana",
popup_return:"Insertar 'return false'",
popup_scrollbars:"Barras de desplazamiento",
popup_statusbar:"Barra de estado",
popup_toolbar:"Barra de herramientas",
popup_menubar:"Barra de men\u00FA",
popup_location:"Barra de localizaci\u00F3n",
popup_resizable:"Permitir cambiar el tama\u00F1o de la ventana",
popup_dependent:"Dependientes (s\u00F3lo Mozilla/Firefox)",
popup_size:"Tama\u00F1o",
popup_position:"Posici\u00F3n (X/Y)",
id:"Id",
style:"Estilo",
classes:"Clases",
target_name:"Nombre del Target",
langdir:"Direcci\u00F3n del lenguaje",
target_langcode:"Lenguaje del Target",
langcode:"C\u00F3digo del lenguaje",
encoding:"Codificaci\u00F3n de caracteres del Target",
mime:"Tipo MIME del Target",
rel:"Relaci\u00F3n p\u00E1gina a target",
rev:"Relaci\u00F3n target a p\u00E1gina",
tabindex:"Indice de tabulaci\u00F3n",
accesskey:"Tecla de acceso",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
link_list:"Lista de v\u00EDnculo"
});
